package com.datacloudsec.scan.cache;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import java.beans.ConstructorProperties;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.io.FileUtils;
import org.dom4j.Document;
import org.dom4j.Element;
import org.dom4j.io.SAXReader;

/* loaded from: com_datacloudsec_scan_cache.jar:com/datacloudsec/scan/cache/Grade.class */
public class Grade {
    private long lastMdfTime;
    private File confFile = new File(Constant.WORK_DIR, "conf/grade.xml");
    private Map<String, List<Item>> items = new HashMap();
    private static Grade instance = new Grade();

    public Map<String, List<Item>> getItems() {
        return this.items;
    }

    private Grade() {
    }

    public static synchronized Grade getInstance() throws Exception {
        instance.loadConf();
        return instance;
    }

    private void loadConf() throws Exception {
        byte[] b;
        String klgeid;
        if (this.confFile.lastModified() != this.lastMdfTime) {
            SAXReader reader = new SAXReader();
            try {
                b = SecretUtil.decryptEncrypt("aes", FileUtils.readFileToByteArray(this.confFile), "anshuyun123SEF@#".getBytes());
            } catch (Exception e) {
                b = FileUtils.readFileToByteArray(this.confFile);
            }
            Document document = reader.read(new ByteArrayInputStream(b));
            Element root = document.getRootElement();
            List<?> eleList = root.elements();
            Map<String, List<Item>> items = new HashMap<>();
            for (Object obj : eleList) {
                Element itemEle = (Element) obj;
                String klgeNumber = ObjectUtil.getString(itemEle.attributeValue("klge-number"), (String) null);
                String devtype = ObjectUtil.getString(itemEle.attributeValue("devtype"), (String) null);
                String ostype = ObjectUtil.getString(itemEle.attributeValue("ostype"), (String) null);
                Integer type = ObjectUtil.getInt(itemEle.attributeValue("type"));
                if (klgeNumber == null) {
                    throw new UEException("检查项编码不能为空");
                }
                if (type == null) {
                    throw new UEException("可用工具不能为空");
                }
                List<String> names = new ArrayList<>();
                for (Object nameObj : itemEle.elements("name")) {
                    Element nameEle = (Element) nameObj;
                    String text = nameEle.getText().trim();
                    if (text.length() > 0) {
                        names.add(text);
                    }
                }
                List<String> nameTypes = new ArrayList<>();
                for (Object nameObj2 : itemEle.elements("name-type")) {
                    Element nameEle2 = (Element) nameObj2;
                    String text2 = nameEle2.getText().trim();
                    if (text2.length() > 0) {
                        nameTypes.add(text2);
                    }
                }
                if (nameTypes.size() == 0 && names.size() == 0) {
                    throw new UEException("策略名不能为空");
                }
                for (String kid : klgeNumber.split(",")) {
                    String[] entry = kid.split("_");
                    Integer index = 1;
                    if (entry.length == 2) {
                        klgeid = entry[0];
                        index = ObjectUtil.getInt(entry[1]);
                    } else {
                        klgeid = kid;
                    }
                    List<Item> itemList = items.get(klgeid);
                    if (itemList == null) {
                        itemList = new ArrayList<>();
                        items.put(klgeid, itemList);
                    }
                    itemList.add(new Item(index, names, nameTypes, type, devtype, ostype));
                }
            }
            this.items = items;
            this.lastMdfTime = this.confFile.lastModified();
        }
    }

    /* loaded from: com_datacloudsec_scan_cache.jar:com/datacloudsec/scan/cache/Grade$Item.class */
    public static class Item {
        private Integer index;
        private List<String> names;
        private List<String> nameTypes;
        private Integer type;
        private String devtype;
        private String ostype;

        public Integer getIndex() {
            return this.index;
        }

        public List<String> getNames() {
            return this.names;
        }

        public List<String> getNameTypes() {
            return this.nameTypes;
        }

        public Integer getType() {
            return this.type;
        }

        public String getDevtype() {
            return this.devtype;
        }

        public String getOstype() {
            return this.ostype;
        }

        public void setIndex(Integer index) {
            this.index = index;
        }

        public void setNames(List<String> names) {
            this.names = names;
        }

        public void setNameTypes(List<String> nameTypes) {
            this.nameTypes = nameTypes;
        }

        public void setType(Integer type) {
            this.type = type;
        }

        public void setDevtype(String devtype) {
            this.devtype = devtype;
        }

        public void setOstype(String ostype) {
            this.ostype = ostype;
        }

        public boolean equals(Object o) {
            if (o == this) {
                return true;
            }
            if (!(o instanceof Item)) {
                return false;
            }
            Item other = (Item) o;
            if (!other.canEqual(this)) {
                return false;
            }
            Object this$index = getIndex();
            Object other$index = other.getIndex();
            if (this$index == null) {
                if (other$index != null) {
                    return false;
                }
            } else if (!this$index.equals(other$index)) {
                return false;
            }
            Object this$names = getNames();
            Object other$names = other.getNames();
            if (this$names == null) {
                if (other$names != null) {
                    return false;
                }
            } else if (!this$names.equals(other$names)) {
                return false;
            }
            Object this$nameTypes = getNameTypes();
            Object other$nameTypes = other.getNameTypes();
            if (this$nameTypes == null) {
                if (other$nameTypes != null) {
                    return false;
                }
            } else if (!this$nameTypes.equals(other$nameTypes)) {
                return false;
            }
            Object this$type = getType();
            Object other$type = other.getType();
            if (this$type == null) {
                if (other$type != null) {
                    return false;
                }
            } else if (!this$type.equals(other$type)) {
                return false;
            }
            Object this$devtype = getDevtype();
            Object other$devtype = other.getDevtype();
            if (this$devtype == null) {
                if (other$devtype != null) {
                    return false;
                }
            } else if (!this$devtype.equals(other$devtype)) {
                return false;
            }
            Object this$ostype = getOstype();
            Object other$ostype = other.getOstype();
            return this$ostype == null ? other$ostype == null : this$ostype.equals(other$ostype);
        }

        protected boolean canEqual(Object other) {
            return other instanceof Item;
        }

        public int hashCode() {
            Object $index = getIndex();
            int result = (1 * 59) + ($index == null ? 0 : $index.hashCode());
            Object $names = getNames();
            int result2 = (result * 59) + ($names == null ? 0 : $names.hashCode());
            Object $nameTypes = getNameTypes();
            int result3 = (result2 * 59) + ($nameTypes == null ? 0 : $nameTypes.hashCode());
            Object $type = getType();
            int result4 = (result3 * 59) + ($type == null ? 0 : $type.hashCode());
            Object $devtype = getDevtype();
            int result5 = (result4 * 59) + ($devtype == null ? 0 : $devtype.hashCode());
            Object $ostype = getOstype();
            return (result5 * 59) + ($ostype == null ? 0 : $ostype.hashCode());
        }

        public String toString() {
            return "Grade.Item(index=" + getIndex() + ", names=" + getNames() + ", nameTypes=" + getNameTypes() + ", type=" + getType() + ", devtype=" + getDevtype() + ", ostype=" + getOstype() + ")";
        }

        @ConstructorProperties({"index", "names", "nameTypes", "type", "devtype", "ostype"})
        public Item(Integer index, List<String> names, List<String> nameTypes, Integer type, String devtype, String ostype) {
            this.index = index;
            this.names = names;
            this.nameTypes = nameTypes;
            this.type = type;
            this.devtype = devtype;
            this.ostype = ostype;
        }
    }

    public static void main(String[] args) throws Exception {
        for (Map.Entry<String, List<Item>> i : getInstance().getItems().entrySet()) {
            System.out.println(i);
        }
    }
}
